@@ -18,6 +18,7 @@ from sqlvalidator.grammar.sql import (
     DatePartExtraction,
     ExceptClause,
     Expression,
+    Float,
     FunctionCall,
     GroupByClause,
     HavingClause,
@@ -179,8 +180,15 @@ class FromStatementParser:
             expression = Parenthesis(argument)
             next_token = next(tokens, None)
         elif next_token == "'" or next_token == '"' or next_token == "`":
-            expression = Table(StringParser.parse(tokens, next_token))
+            table_name = StringParser.parse(tokens, next_token)
             next_token = next(tokens, None)
+            while next_token == ".":
+                right_hand, next_token = ExpressionParser.parse(
+                    tokens,
+                    is_right_hand=True,
+                )
+                table_name = ChainedColumns(table_name, right_hand)
+            expression = Table(table_name)
         elif next_token == "[":
             argument_tokens, next_token = get_tokens_until_one_of(
                 tokens, stop_words=["]"]
@@ -493,16 +501,19 @@ class ExpressionParser:
         can_be_type=False,
         can_alias=True,
         until_one_of=None,
+        first_token=None,
     ) -> Tuple[Expression, Any]:
         until_one_of = until_one_of or []
 
-        main_token = next(tokens)
+        main_token = first_token or next(tokens)
         next_token = None
 
         if main_token in String.QUOTES:
             expression = StringParser.parse(tokens, main_token)
         elif main_token.isdigit():
             expression = Integer(main_token)
+        elif main_token.replace(".", "").isdigit():
+            expression = Float(main_token)
         elif lower(main_token) in Boolean.BOOLEAN_VALUES:
             expression = Boolean(main_token)
         elif lower(main_token) in Null.VALUES:
@@ -616,8 +627,8 @@ class ExpressionParser:
                     )
                 else:
                     argument_tokens = get_tokens_until_closing_parenthesis(tokens)
-                    arguments_can_be_type = (
-                        "," in argument_tokens or lower(main_token) == "if"
+                    arguments_can_be_type = can_be_type or any(
+                        lower(t) == "timestamp_trunc" for t in argument_tokens
                     )
                     arguments = ExpressionListParser.parse(
                         iter(argument_tokens), can_be_type=arguments_can_be_type
@@ -647,6 +658,13 @@ class ExpressionParser:
             elif next_token is not None and main_token == "-" and next_token.isdigit():
                 expression = Integer(-int(next_token))
                 next_token = next(tokens, None)
+            elif (
+                next_token is not None
+                and main_token == "-"
+                and next_token.replace(".", "").isdigit()
+            ):
+                expression = Float(-float(next_token))
+                next_token = next(tokens, None)
             elif (
                 lower(main_token) in String.PREFIXES
                 and next_token is not None
@@ -725,16 +743,24 @@ class ExpressionParser:
             symbol = next_token
             if lower(next_token) == "is":
                 next_next_token = next(tokens)
+                first_token = None
                 if lower(next_next_token) == "not":
                     symbol = "is not"
                 else:
-                    tokens, _ = get_tokens_until_one_of(
-                        tokens, [], first_token=next_next_token
-                    )
-                    tokens = iter(tokens)
+                    first_token = next_next_token
+            elif lower(next_token) == "not":
+                next_next_token = next(tokens)
+                first_token = None
+                if lower(next_next_token) == "in":
+                    symbol = "not in"
+                else:
+                    first_token = next_next_token
 
             right_hand, next_token = ExpressionParser.parse(
-                tokens, is_right_hand=True, until_one_of=until_one_of
+                tokens,
+                is_right_hand=True,
+                until_one_of=until_one_of,
+                first_token=first_token,
             )
             expression = Condition(expression, symbol, right_hand)
         elif lower(next_token) == "between":
