@@ -247,6 +247,9 @@ class WhereClause(Expression):
             )
         return errors
 
+    def __eq__(self, other):
+        return type(self) == type(other) and self.value == other.value
+
 
 class GroupByClause(Expression):
     def __init__(self, *args, rollup=False):
@@ -742,6 +745,18 @@ class Integer(Expression):
         return int
 
 
+class Float(Expression):
+    def __init__(self, value):
+        super().__init__(float(value))
+
+    def __str__(self):
+        return str(self.value)
+
+    @property
+    def return_type(self):
+        return float
+
+
 class Null(Expression):
     VALUES = ("null",)
 
@@ -924,7 +939,7 @@ class Addition(ArithmaticOperator):
 
 
 class BitwiseOperation(Expression):
-    OPERATORS = ("&", "|", "^")
+    OPERATORS = ("&", "|", "^", "||", "<<", ">>", "#")
 
     def __init__(self, expression, predicate, right_hand):
         super().__init__(expression)
@@ -1159,7 +1174,19 @@ class UsingClause(Expression):
 
 
 class Condition(Expression):
-    PREDICATES = ("=", ">", "<", "<=", ">=", "is", "like", "<>", "in")
+    PREDICATES = (
+        "=",
+        ">",
+        "<",
+        "<=",
+        ">=",
+        "is",
+        "like",
+        "<>",
+        "in",
+        "not",
+        "contains",
+    )
 
     def __init__(self, expression, predicate, right_hand):
         super().__init__(expression)
@@ -1176,6 +1203,14 @@ class Condition(Expression):
             self.value, self.predicate, self.right_hand
         )
 
+    def __eq__(self, other):
+        return (
+            type(self) == type(other)
+            and self.value == other.value
+            and self.predicate == other.predicate
+            and self.right_hand == other.right_hand
+        )
+
     def validate(self, known_fields):
         errors = super().validate(known_fields)
         errors += self.value.validate(known_fields)
